<div align="center">

<img src="assets/Logo.svg" alt="Zenyx engine" width="350"/>

![Version](https://img.shields.io/badge/version-0.1.0-blue)
![License](https://img.shields.io/gitlab/license/Caznix/Zenyx)
![Build](https://img.shields.io/github/actions/workflow/status/Caznix/Zenyx/rust.yml?branch=main)

![platform](https://img.shields.io/badge/platform-windows%20%7C%20linux%20%7C%20macos-informational)

</div>

---

# What is Zenyx?

Zenyx is an in-development game engine leveraging the power of [wgpu](https://github.com/gfx-rs/wgpu) for graphics rendering and [winit](https://github.com/rust-windowing/winit) for window management. Built with Rust, Zenyx aims to be an intuitive and innovative game engine, designed to adapt to various workflows while introducing new possibilities for game development.

## Planned Features

> 🚀 Note: The following features represent the intended direction of Zenyx and are not fully implemented at this stage.

### **Zenyx is being designed with the following capabilities in mind:**

- ✨ **Cross-Platform Compatibility:** Targeting Windows, Linux, and macOS.
- ⚡ **Performance and Safety:** Built with Rust to provide both speed and memory safety.
- 🎯 **Intuitive and Extensible Design:** Focusing on user-friendly workflows and highly customizable tools.
- 🔧 **Modular Architecture:** Designed with a modular structure for straightforward customization.
- 🛠️ **Integrated Toolset:** Envisioning built-in tools for spatial audio and level editing.
- 📦 **Efficient Asset Management:** Developing a robust resource handling system.
- 🎲 **Performant Physics Engine:** Zenyx Makes use of [Rapier2D](https://docs.rs/rapier2d/latest/rapier2d/) & [Rapier3D](https://docs.rs/rapier3d/latest/rapier3d/)
- 🗂️ **Advanced Scene Management:** Designing flexible tools for organizing game scenes.

### **Current Limitations:**

Currently, Zenyx faces certain limitations due to its early stage of development and the capabilities of its underlying rendering backend, wgpu:

- **No Hardware Ray Tracing:** As wgpu currently only supports standard rasterization pipelines, Zenyx inherits this limitation. Hardware ray tracing is not yet available. You can follow the progress of ray tracing support in wgpu [here](https://github.com/gfx-rs/wgpu/issues/6762).
- **Alpha software:** Zenyx is in the initial phases of development. It is not yet suitable for any practical use cases. Many of the features listed above are still goals and have not been implemented.
- **Limited macOS Support:** While macOS (and or IOS) is a target platform, it currently requires MoltenVK due to wgpu's lack of native Metal support. This might introduce additional dependencies, potential compatibility issues, or generally unintended behavior on such platforms
- **Incomplete Documentation and Tooling:** As the engine is under active development, comprehensive documentation and a full suite of built-in tools are not yet available, however they are still planned for the near future.

## FAQ

<details>
<summary><b>What platforms does Zenyx support?</b></summary>

Zenyx primarily supports Windows and Linux, with secondary support for macOS. See the
[Platform support table](#what-platforms-will-be-supported-in-the-future) for more
information.

</details>

<details>
<summary><b>Is Zenyx ready for production use?</b></summary>

Zenyx is currently in early development and is not yet ready for any simple use
cases, but we're working hard to make it the best it can be before we release
1.0. If this interests you, and you're interested in helping, please check out
the [contribution section](CONTRIBUTING.md) for the ways you can help.

</details>

<details>
<summary><b>How can I contribute to Zenyx?</b></summary>

We welcome contributions! Please check our contribution guidelines and open a
pull request on GitHub, if you aren't a developer, you can also report bugs or
feature requests on our [issue tracker](https://codeberg.org/Zenyx/zenyx/issues).
For more information, please see the [Contributing section](#contributing).

</details>

<details>
<summary><b>What are the system requirements?</b></summary>

Detailed system requirements will be provided as the engine matures. Currently,
the only requirement is a modern OS and a system with atleast a semi-recent GPU.

</details>

<details>
<summary><b>Is Zenyx free to use?</b></summary>

Yes, Zenyx is open-source software licensed under MIT. You can Modify,
Distribute, and use Zenyx for any purpose you wish.

</details>

## What platforms will be supported in the future?

|  Platform  | Support Priority | Status | Notes                                                                                                                                                                                                                                                                  |
|:----------:|:----------------:|:------:|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|  Windows   |     Primary      |   ✅    |                                                                                                                                                                                                                                                                        |
| Linux/*BSD |     Primary      |   ✅    |                                                                                                                                                                                                                                                                        |
|   macOS    |    Secondary     |   ⚠️   | The current main set of maintainers do not own any native MacOS devices to perform tests with.                                                                                                                                                                         |
|  Android   |   Help wanted    |   ❓    |                                                                                                                                                                                                                                                                        |
|    iOS     |   Not planned    |   ❓    |                                                                                                                                                                                                                                                                        |
|    Web     |       TBD        |   ❓    |                                                                                                                                                                                                                                                                        |
|  Consoles  |   Not planned    |   ⛔    | Consoles require specific dev kits,proprietary licenses, and substantial fees that we (Nonsensical-dev,the Zenyx maintainers,and the open source contributors) currently do not have the capacity for. This may change in the future but most likely will not be soon. |

# Documentation

## Getting Started

Zenyx is currently in a pre-release state and is not yet ready for general use.
Keep an eye on this section for updates on when you can start using Zenyx.

# Contributing

We encourage community involvement in the development of Zenyx! If you're interested in contributing,
please review our [Contribution Guide](CONTRIBUTING.md) for our coding standards and community guidelines.

You can contribute in various ways, even if you're not a developer. Spreading the word about Zenyx,
reporting any bugs you encounter, suggesting new features,
and helping us improve our documentation are all valuable contributions.

If you are interested in contributing code to Zenyx, please follow the platform-specific instructions below:

## Prerequisites (all platforms)

1. Ensure you have [Rust](https://www.rust-lang.org/tools/install) installed on your system.

2. Make sure you have [git](https://git-scm.com/downloads) installed for version control.

## Building

**1**. Clone the Zenyx repository from your favorite mirror:

    git clone https://codeberg.org/Zenyx/zenyx

**2**. Navigate to the project directory:

    cd ./Zenyx

**3**. Build the project using Cargo:

    cargo run

# Press kit

### Text

<img src="assets/Logo.png" width="256" alt="Zenyx Typeface">

### Colored badges

<img src="assets/Badge.png" width="128" alt="Zenyx Logo">
